@@ -154,30 +154,43 @@ class ChEMBLTargetCofactorProvider(StashableBase):
                     for taD in taDL:
                         if taD["assay_type"] in ["B", "F"]:
                             if taD["standard_units"] == "nM":
-                                pV = -math.log10(float(taD["standard_value"]) * 10.0e-9)
-                                actD = {
-                                    "cofactor_id": taD["molecule_chembl_id"],
-                                    "assay_id": taD["assay_chembl_id"],
-                                    "assay_description": taD["assay_description"],
-                                    "measurement_type": "p" + taD["standard_type"],
-                                    "measurement_value": round(pV, 2),
-                                }
-                                actL.append(actD)
+                                try:
+                                    pV = -math.log10(float(taD["standard_value"]) * 10.0e-9)
+                                    actD = {
+                                        "cofactor_id": taD["molecule_chembl_id"],
+                                        "assay_id": taD["assay_chembl_id"],
+                                        "assay_description": taD["assay_description"],
+                                        "measurement_type": "p" + taD["standard_type"],
+                                        "measurement_value": round(pV, 2),
+                                        "smiles": taD["canonical_smiles"],
+                                        "molecule_name": taD["molecule_name"],
+                                        "inchi_key": taD["inchi_key"],
+                                        "action": taD["action"],
+                                        "moa": taD["moa"],
+                                        "max_phase": taD["max_phase"],
+                                    }
+
+                                    actL.append(actD)
+                                except Exception as e:
+                                    logger.exception("Failing for tAD %r with %s", taD, str(e))
+
                     # ---
                     actL = self.__activityListSelect(actL, crmpObj, maxActivity=maxActivity)
                     # ---
                     rD = {
                         "entry_id": entryId,
                         "entity_id": entityId,
-                        "unp_id": unpId,
-                        "target_chembl_id": chemblId,
+                        "query_uniprot_id": unpId,
+                        "query_id": chemblId,
+                        "query_id_type": "ChEMBL",
                         "provenance_source": provenanceSource,
                         "reference_scheme": refScheme,
                         "assignment_version": assignVersion,
                         "query_taxonomy_id": int(queryTaxId),
                         "target_taxonomy_id": int(matchD["targetTaxId"]),
                         "target_beg_seq_id": matchD["targetStart"],
-                        "target_end_seq_id": matchD["targetEnd"],
+                        "query_beg_seq_id": matchD["queryStart"],
+                        "align_length": matchD["alignLen"],
                         "taxonomy_match_status": matchD["taxonomyMatchStatus"] if "taxonomyMatchStatus" in matchD else None,
                         "lca_taxonomy_id": matchD["lcaTaxId"] if "lcaTaxId" in matchD else None,
                         "lca_taxonomy_name": matchD["lcaTaxName"] if "lcaTaxName" in matchD else None,
