@@ -103,27 +103,36 @@ class DrugBankTargetCofactorProvider(StashableBase):
                 tL = matchD["target"].split("|")
                 entryId = tL[0].split("_")[0]
                 entityId = tL[0].split("_")[1]
-                #
-                dbIdL = dbP.getCofactors(unpId)
+                # --
+                dbDL = dbP.getCofactors(unpId)
                 # --
                 cfDL = []
-                for dbId in dbIdL:
-                    cfD = {"cofactor_id": dbId}
+                for dbD in dbDL:
+                    cfD = {}
+                    cfD["cofactor_id"] = dbD["drugbank_id"]
+                    cfD["molecule_name"] = dbD["name"]
+                    cfD["description"] = dbD["description"]
+                    cfD["moa"] = dbD["moa"]
+                    cfD["pharmacology"] = dbD["pharmacology"]
+                    cfD["inchi_key"] = dbD["inchi_key"]
+                    cfD["smiles"] = dbD["smiles"]
+                    cfD["pubmed_ids"] = dbD["pubmed_ids"]
                     cfDL.append(self.__addLocalIds(cfD, crmpObj))
                 # --
                 rD = {
                     "entry_id": entryId,
                     "entity_id": entityId,
-                    "unp_id": unpId,
-                    "target_id": unpId,
-                    "target_id_type": "DrugBank",
+                    "query_uniprot_id": unpId,
+                    "query_id": unpId,
+                    "query_id_type": "DrugBank",
                     "provenance_source": provenanceSource,
                     "reference_scheme": refScheme,
                     "assignment_version": assignVersion,
                     "query_taxonomy_id": int(queryTaxId),
                     "target_taxonomy_id": int(matchD["targetTaxId"]),
                     "target_beg_seq_id": matchD["targetStart"],
-                    "target_end_seq_id": matchD["targetEnd"],
+                    "query_beg_seq_id": matchD["queryStart"],
+                    "align_length": matchD["alignLen"],
                     "taxonomy_match_status": matchD["taxonomyMatchStatus"] if "taxonomyMatchStatus" in matchD else None,
                     "lca_taxonomy_id": matchD["lcaTaxId"] if "lcaTaxId" in matchD else None,
                     "lca_taxonomy_name": matchD["lcaTaxName"] if "lcaTaxName" in matchD else None,
